@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/borg
 ;; Keywords: tools
 
-;; Package-Version: 4.2.2
-;; Package-Revision: v4.2.2-0-g5b192d8d1a42
+;; Package-Version: 4.3.0
+;; Package-Revision: v4.3.0-0-g28e6ba50fab8
 ;; Package-Requires: (
 ;;     (emacs "27.1")
 ;;     (epkg   "4.1")
@@ -547,17 +547,24 @@ otherwise."
       (shell-command "make autoloads")))
   (borg-do-drones (drone)
     (message "\n--- [%s] ---\n" drone)
-    (cond
-     ((borg--drone-disabled-p drone)
-      (message "Skipped (Disabled)"))
-     ((let ((min (cdr (assoc drone borg-minimal-emacs-alist))))
-        (and min (version< emacs-version min)
-             (message "Skipped (Requires Emacs >= %s)" min))))
-     ((not (file-exists-p (borg-worktree drone)))
-      (message "Skipped (Missing)"))
-     ((and quick (borg-get-all drone "build-step"))
-      (message "Skipped (Expensive to build)"))
-     ((borg-build drone nil native))))
+    (let ((dir (borg-worktree drone)))
+      (cond
+       ((borg--drone-disabled-p drone)
+        (message "Skipped (Disabled)"))
+       ((let ((min (cdr (assoc drone borg-minimal-emacs-alist))))
+          (and min (version< emacs-version min)
+               (message "Skipped (Requires Emacs >= %s)" min))))
+       ((not (file-exists-p dir))
+        (message "Skipped (Missing)"))
+       ((static-if (functionp 'directory-empty-p) ;since Emacs 28.1
+            (directory-empty-p dir)
+          (and (file-directory-p dir)
+               (null (directory-files
+                      dir nil directory-files-no-dot-files-regexp t))))
+        (message "Skipped (Empty directory)"))
+       ((and quick (borg-get-all drone "build-step"))
+        (message "Skipped (Expensive to build)"))
+       ((borg-build drone nil native)))))
   (borg-batch-rebuild-init))
 
 (defun borg-batch-rebuild-init ()
@@ -807,7 +814,7 @@ and optional NATIVE are both non-nil, then also compile natively."
         (with-temp-buffer
           (let ((coding-system-for-write 'utf-8-emacs-unix))
             (write-region (and (functionp 'autoload-rubric)
-                               (autoload-rubric file "package" nil))
+                               (autoload-rubric file "package" t))
                           nil file nil 'silent)))
         (borg--silence-loaddefs-generate
           (let ((generated-autoload-file file))
@@ -944,12 +951,8 @@ and optional NATIVE are both non-nil, then also compile natively."
 Export each file located on `borg-info-path' if its name matches
 `borg-maketexi-filename-regexp' and the `TEXINFO_DIR_HEADER'
 export keyword is set in its content.  If optional FILES is
-non-nil, then try those files instead.  On Emacs 25 this function
-doesn't do anything."
-  ;; ... because turning on `org-mode' (via `find-file-noselect')
-  ;; results in an error that I do not wish to investigate.
-  (when (and (> emacs-major-version 25)
-             (or files borg-maketexi-filename-regexp))
+non-nil, then try those files instead."
+  (when (or files borg-maketexi-filename-regexp)
     (let ((repo (borg-worktree clone))
           (exclude (borg-get-all clone "no-maketexi")))
       (dolist (file (or files
